diff src/vim9.h @ 23553:5c094273c015 v8.2.2319

patch 8.2.2319: "exptype_T" can be read as "expected type" Commit: https://github.com/vim/vim/commit/657137ca487c60d63989236115115161def270a5 Author: Bram Moolenaar <Bram@vim.org> Date: Sat Jan 9 15:45:23 2021 +0100 patch 8.2.2319: "exptype_T" can be read as "expected type" Problem: "exptype_T" can be read as "expected type". Solution: Rename to "exprtype_T", expression type.
author Bram Moolenaar <Bram@vim.org>
date Sat, 09 Jan 2021 16:00:04 +0100
parents f90e429453fd
children f50ee1ae4d9b
line wrap: on
line diff
--- a/src/vim9.h
+++ b/src/vim9.h
@@ -105,12 +105,12 @@ typedef enum {
     ISN_ADDLIST,    // add two lists
     ISN_ADDBLOB,    // add two blobs
 
     // operation with two arguments; isn_arg.op.op_type is exptype_T
     ISN_OPNR,
     ISN_OPFLOAT,
     ISN_OPANY,
 
     // comparative operations; isn_arg.op.op_type is exptype_T, op_ic used
     ISN_COMPAREBOOL,
     ISN_COMPARESPECIAL,
     ISN_COMPARENR,
@@ -217,7 +217,7 @@ typedef struct {
 
 // arguments to ISN_OPNR, ISN_OPFLOAT, etc.
 typedef struct {
-    exptype_T	op_type;
+    exprtype_T	op_type;
     int		op_ic;	    // TRUE with '#', FALSE with '?', else MAYBE
 } opexpr_T;
@@ -105,12 +105,12 @@ typedef enum {
     ISN_ADDBLOB,    // add two blobs
 
-    // operation with two arguments; isn_arg.op.op_type is exptype_T
+    // operation with two arguments; isn_arg.op.op_type is exprtype_T
     ISN_OPNR,
     ISN_OPFLOAT,
@@ -105,12 +105,12 @@ typedef enum {
     ISN_OPANY,
 
-    // comparative operations; isn_arg.op.op_type is exptype_T, op_ic used
+    // comparative operations; isn_arg.op.op_type is exprtype_T, op_ic used
     ISN_COMPAREBOOL,
     ISN_COMPARESPECIAL,